@@ -51,6 +51,7 @@
 
 package com.openexchange.custom.parallels.impl;
 
+import static com.openexchange.java.Autoboxing.I;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.util.Arrays;
@@ -88,74 +89,74 @@ public final class ParallelsHostnameService implements HostnameService {
     }
 
     private String getHostname(final int userId, final int contextId, boolean isGuest) {
-        if (contextId > 0) {
-            final ContextService service = Services.getService(ContextService.class);
-            String hostname = null;
-            String guestHostname = null;
-            Context ctx;
-            try {
-                ctx = service.getContext(contextId);
-                final String[] login_mappings = ctx.getLoginInfo();
-                final ConfigurationService configservice = Services.getService(ConfigurationService.class);
+        if (contextId <= 0) {
+            LOG.error("getHostname: Got context with id {}, dont generating any hostname", I(contextId));
+            return null;
+        }
 
-                // load suffix for branding string dynamically in loginmappings
-                final String suffix_branded = configservice.getProperty(ParallelsOptions.PROPERTY_BRANDING_SUFFIX);
-                LOG.debug("getHostname: Loaded loginmappings {} for context {}", Arrays.toString(login_mappings), contextId);
-                if( null != suffix_branded && suffix_branded.length() != 0) {
-                    for (final String login_mapping : login_mappings) {
-                        if(login_mapping.startsWith(suffix_branded)){
-                            /**
-                             *
-                             *  We found our mapping which contains the branded URL!
-                             *
-                             *  Now split up the string to get the URL part
-                             *
-                             */
-                            final String[] URL_ = login_mapping.split("\\|\\|"); // perhaps replace with substring(start,end) if would be faster
-                            if (3 <= URL_.length) {
-                                hostname = URL_[2];
-                                LOG.debug("getHostname: Successfully resolved HOST to {} for branded context {}", hostname, contextId);
-                                if (4 <= URL_.length) {
-                                    guestHostname = URL_[3];
-                                    LOG.debug("getHostname: Successfully resolved guest HOST to {} for branded context {}", guestHostname, contextId);
-                                }
-                            } else {
-                                LOG.error("getHostname: Could not split up branded host {} login mapping for context {}", login_mapping, contextId);
+        final ContextService service = Services.getService(ContextService.class);
+        String hostname = null;
+        String guestHostname = null;
+        Context ctx;
+        try {
+            ctx = service.getContext(contextId);
+            final String[] login_mappings = ctx.getLoginInfo();
+            final ConfigurationService configservice = Services.getService(ConfigurationService.class);
+
+            // load suffix for branding string dynamically in login-mappings
+            final String suffix_branded = configservice.getProperty(ParallelsOptions.PROPERTY_BRANDING_SUFFIX);
+            LOG.debug("getHostname: Loaded loginmappings {} for context {}", Arrays.toString(login_mappings), I(contextId));
+            if( null != suffix_branded && suffix_branded.length() != 0) {
+                for (final String login_mapping : login_mappings) {
+                    if(login_mapping.startsWith(suffix_branded)){
+                        /**
+                         *
+                         *  We found our mapping which contains the branded URL!
+                         *
+                         *  Now split up the string to get the URL part
+                         *
+                         */
+                        final String[] URL_ = login_mapping.split("\\|\\|"); // perhaps replace with substring(start,end) if would be faster
+                        if (3 <= URL_.length) {
+                            hostname = URL_[2];
+                            LOG.debug("getHostname: Successfully resolved HOST to {} for branded context {}", hostname, I(contextId));
+                            if (4 <= URL_.length) {
+                                guestHostname = URL_[3];
+                                LOG.debug("getHostname: Successfully resolved guest HOST to {} for branded context {}", guestHostname, I(contextId));
                             }
+                        } else {
+                            LOG.error("getHostname: Could not split up branded host {} login mapping for context {}", login_mapping, I(contextId));
                         }
                     }
                 }
-                if (null == hostname){
-                    // now host was provisioned, load fallback from configuration
-                    hostname = configservice.getProperty(ParallelsOptions.PROPERTY_BRANDING_FALLBACKHOST);
-                    // use systems getHostname() if no fallbackhost is set
-                    if( null == hostname || hostname.length() == 0 ) {
-                        try {
-                            hostname = InetAddress.getLocalHost().getCanonicalHostName();
-                        } catch (UnknownHostException e) { }
-                    }
-                    if( null == hostname || hostname.length() == 0 ) {
-                        LOG.warn("getHostname: Unable to determine any hostname for context {}", contextId);
-                    }
-                }
-                if (null == guestHostname) {
-                    // no guest host was provisioned, load fallback from configuration
-                    guestHostname = configservice.getProperty(ParallelsOptions.PROPERTY_BRANDING_GUESTFALLBACKHOST);
-                    // use systems getHostname() if no fallbackhost is set
-                    if (Strings.isEmpty(guestHostname)) {
-                        guestHostname = hostname;
-                        LOG.debug("getHostname: no guest host configured, falling back to HOST {} for branded context {}", guestHostname, contextId);
-                    }
-                }
-            } catch (final OXException e) {
-                LOG.error("", e);
             }
-
-            return isGuest ? guestHostname : hostname;
-        } else {
-            LOG.error("getHostname: Got context with id {}, dont generating any hostname", contextId);
-            return null;
+            if (null == hostname){
+                // now host was provisioned, load fallback from configuration
+                hostname = configservice.getProperty(ParallelsOptions.PROPERTY_BRANDING_FALLBACKHOST);
+                // use systems getHostname() if no fallbackhost is set
+                if( null == hostname || hostname.length() == 0 ) {
+                    try {
+                        hostname = InetAddress.getLocalHost().getCanonicalHostName();
+                    } catch (UnknownHostException e) { }
+                }
+                if( null == hostname || hostname.length() == 0 ) {
+                    LOG.warn("getHostname: Unable to determine any hostname for context {}", I(contextId));
+                }
+            }
+            if (null == guestHostname) {
+                // no guest host was provisioned, load fallback from configuration
+                guestHostname = configservice.getProperty(ParallelsOptions.PROPERTY_BRANDING_GUESTFALLBACKHOST);
+                // use systems getHostname() if no fallbackhost is set
+                if (Strings.isEmpty(guestHostname)) {
+                    guestHostname = hostname;
+                    LOG.debug("getHostname: no guest host configured, falling back to HOST {} for branded context {}", guestHostname, I(contextId));
+                }
+            }
+        } catch (final OXException e) {
+            LOG.error("", e);
         }
+
+        return isGuest ? guestHostname : hostname;
     }
 
 }
